
import gwinc
import opts
import gwinc_kagra.kagra_ref as kagra_ref

import numpy as np
import matplotlib.pyplot as plt

from numpy       import pi
from gwinc_kagra import gwinc_kagra

def cmp(fig, freq, n1, n0, ylim = 0.05, lb1 = 'gwinc_kagra',\
                                        lb0 = 'kagra_sensitivity'):
    ax  = fig.add_subplot(2, 1, 1)
    ax.loglog(freq, n1, color='red',  label=lb1, linestyle='-')
    ax.loglog(freq, n0, color='blue', label=lb0, linestyle=':', linewidth=3)
    ax.legend(fontsize=13)

    ax.xaxis.grid(True)
    ax.yaxis.grid(True)
    ax.set_xlim([5, 5000])
    ax.set_ylim([1e-24, 5e-21])
    ax.set_ylabel(u"Strain [1/\u221AHz]")
    ax.set_xticklabels([])

    ax  = fig.add_subplot(2, 1, 2)
    ax.semilogx(freq, n1/n0-1)
    ax.xaxis.grid(True)
    ax.yaxis.grid(True)
    ax.set_xlim([5, 5000])
    ax.set_ylim([-ylim, ylim])
    ax.set_xlabel('Frequency [Hz]')
    ax.set_ylabel("Relative difference")

options, args = opts.getopts('cfpdysv')

if options.data:
    if options.conf == 'BRSEsqz':
        nn  = np.loadtxt('dat/spectrum_BRSE.txt')
        n0  = nn[:,5]
        lb0 = 'JGW-T1707038'
        options.plot = 'hsh'
        options.ylim = 0.3

    elif options.conf.find('RSE') >= 0:
        nn  = np.loadtxt('dat/spectrum_'+options.conf+'.txt')
        n0  = nn[:,6]
        lb0 = 'JGW-T1707038'

    else:
        nn  = np.loadtxt('dat/KAGRAplus'+options.conf+'.txt')
        n0  = nn[:,1]
        lb0 = 'JGW-T1809537'

    nn  = kagra_ref.sensitivity(options.conf, options.verbose)
    n1  = nn[options.plot]
    fr  = nn['f']
    lb1 = 'kagra_sensitivity'
    png = 'figs/'+options.conf+'_d.png'

else:
    nn  = kagra_ref.sensitivity(options.conf, options.verbose)
    fr  = nn['f']
    n0  = nn[options.plot]
    lb0 = 'kagra_sensitivity'

    ifo = gwinc.load_ifo(options.ifo)
    nn  = gwinc_kagra(fr, ifo, options.conf, options.verbose)
    n1  = kagra_ref.noise_gwinc(options.plot, nn)
    lb1 = 'gwinc_kagra'
    png = 'figs/'+options.conf+'.png'

title = 'bKAGRA ('+options.conf+')' if options.conf.find('RSE') >= 0 \
   else 'KAGRA+ ('+options.conf+')'

left  = 0.20 if float(options.ylim) >  0.01  else 0.18
left  = 0.25 if float(options.ylim) == 0.001 else left

fig = plt.figure(figsize=(4,6), dpi=100, facecolor='white')
plt.subplots_adjust(top=0.95, left=left, right=0.98, hspace=0.1)

cmp(fig, fr, n1, n0, float(options.ylim), lb1, lb0)
fig.text(0.51, 0.99, title, ha='center', va='top', size=15)
fig.show()

if options.save:
    plt.savefig(png, dpi = 200)
    print 'Figure is saved as '+png
