
import numpy as np

def seismic(f, ifo):
    """Seismic noise.

    Return (noise, noise_vertical, noise_horizontal)


    """
    #####seismic noise#####
    # fitting function of the seismic noise calculated by R. Takahashi.
    #
    #hseisorig = 2*2*np.sqrt((4.1e-17*f**(-6.8))**2+
    #                        (1.9e-16*f**(-8))  **2+
    #                        (1.8e-18*f**(-5.7))**2)

    L = ifo.Infrastructure.Length       # Length of arm cavities [m]

    # squared except for factor of 4 (multiplied later)
    n = 2*2*((4.1e-17*f**(-6.8))**2+ \
             (1.9e-16*f**(-8.0))**2+ \
             (1.8e-18*f**(-5.7))**2) *L**2

    # Convert into Strain PSD (4 TMs)
    n  *= 4 * ifo.gwinc.dhdl_sqr

    return n
